@@ -55,9 +55,9 @@ class DailyLaborWorktime(DataClassJsonMixin):
 class FormatTarget(Enum):
     DETAILS = "details"
     """日毎・人毎の詳細な値を出力する"""
-    BY_USER = "by_user"
+    TOTAL_BY_USER = "total_by_user"
     """人毎の作業時間を出力する"""
-    BY_PROJECT = "by_project"
+    TOTAL_BY_PROJECT = "total_by_project"
     """プロジェクト毎の作業時間を出力する"""
     TOTAL = "total"
     """合計の作業時間を出力する"""
@@ -110,14 +110,14 @@ def create_df_with_format_column_list_per_project(df_actual_times: pandas.DataFr
     )
 
 
-def create_df_with_format_by_user(df_intermediate: pandas.DataFrame) -> pandas.DataFrame:
-    """`--format by_user`に対応するDataFrameを生成する。
+def create_df_with_format_total_by_user(df_intermediate: pandas.DataFrame) -> pandas.DataFrame:
+    """`--format total_by_user`に対応するDataFrameを生成する。
 
     Args:
-        df (pd.DataFrame): [description]
+        df (pd.DataFrame): 中間出力用のDataFrame
 
     Returns:
-        pd.DataFrame: [description]
+        pd.DataFrame: `--format total_by_user`に対応するDataFrame.user_idの辞書順(大文字小文字を区別しない).
     """
     df = df_intermediate.groupby("user_id")[["worktime_planned", "worktime_actual", "worktime_monitored"]].sum()
     df_user = df_intermediate.groupby("user_id").first()[["username", "biography"]]
@@ -127,6 +127,7 @@ def create_df_with_format_by_user(df_intermediate: pandas.DataFrame) -> pandas.D
     df["monitor_rate"] = df["worktime_monitored"] / df["worktime_actual"]
     df["monitor_diff"] = df["worktime_actual"] - df["worktime_monitored"]
 
+    df.sort_index(key=lambda e: e.str.lower(), inplace=True)
     df.reset_index(inplace=True)
     return (
         df[
@@ -144,18 +145,17 @@ def create_df_with_format_by_user(df_intermediate: pandas.DataFrame) -> pandas.D
         ]
         .round(2)
         .replace(DEFAULT_TO_REPLACE_FOR_VALUE)
-        .sort_values(by=["user_id"])
     )
 
 
-def create_df_with_format_by_project(df_intermediate: pandas.DataFrame) -> pandas.DataFrame:
-    """`--format by_project`に対応するDataFrameを生成する。
+def create_df_with_format_total_by_project(df_intermediate: pandas.DataFrame) -> pandas.DataFrame:
+    """`--format total_by_project`に対応するDataFrameを生成する。
 
     Args:
-        df (pd.DataFrame): [description]
+        df (pd.DataFrame): 中間出力用のDataFrame
 
     Returns:
-        pd.DataFrame: [description]
+        pd.DataFrame: `--format total_by_project`に対応するDataFrame。project_titleの辞書順(大文字小文字を区別しない).
     """
 
     df = df_intermediate.groupby("project_id")[["worktime_planned", "worktime_actual", "worktime_monitored"]].sum()
@@ -182,7 +182,7 @@ def create_df_with_format_by_project(df_intermediate: pandas.DataFrame) -> panda
         ]
         .round(2)
         .replace(DEFAULT_TO_REPLACE_FOR_VALUE)
-        .sort_values(by=["project_title"])
+        .sort_values(by=["project_title"], key=lambda e: e.str.lower())
     )
 
 
@@ -268,15 +268,13 @@ def create_df_with_format_details(
         insert_sum_column: 合計列を追加する
 
     Returns:
-        pd.DataFrame: `--format details`に対応するDataFrame
+        pd.DataFrame: `--format details`に対応するDataFrame.行方向は日付順、列方向はuser_idの辞書順(大文字小文字を区別しない).
 
-    Notes:
-        fork元のannofabcliには、AnnoFabプロジェクトのproject_idの一覧も記載されていたが、なくても問題ないため省く。
     """
     SUM_COLUMN_NAME = "総合計"
     SUM_ROW_NAME = "合計"
 
-    # TODO 同姓同名だった場合、正しく集計されない
+    # 注意：同姓同名だった場合、正しく集計されない
     df = df_intermediate.groupby(["date", "username"])[
         ["worktime_actual", "worktime_monitored", "worktime_planned"]
     ].sum()
@@ -290,7 +288,7 @@ def create_df_with_format_details(
 
         df = df.append(df_sum_by_date)
 
-    # ヘッダが [member_id, value] になるように設定する
+    # ヘッダが [user_id, value] になるように設定する
     df2 = df.stack().unstack([1, 2])
 
     # 日付が連続になるようにする
@@ -298,7 +296,7 @@ def create_df_with_format_details(
         df2.index
     )
     df2 = df2.append([pandas.Series(name=date, dtype="float64") for date in not_exists_date_set], sort=True)
-
+    df2.sort_index(inplace=True)
     # 作業時間がNaNの場合は0に置換する
     df2.replace(
         {
@@ -309,7 +307,15 @@ def create_df_with_format_details(
         inplace=True,
     )
 
-    username_list = list(df_intermediate["username"].unique())
+    # user_idの辞書順（大文字小文字区別しない）のユーザのDataFrameを生成する。
+    df_user = (
+        df_intermediate[["user_id", "username", "biography"]]
+        .drop_duplicates()
+        .set_index("user_id")
+        .sort_index(key=lambda x: x.str.lower())
+    )
+
+    username_list = list(df_user["username"])
     if insert_sum_column:
         username_list = [SUM_COLUMN_NAME] + username_list
 
@@ -319,27 +325,34 @@ def create_df_with_format_details(
         tmp_sum_row.name = SUM_ROW_NAME
         df2 = pandas.concat([pandas.DataFrame([tmp_sum_row]), df2])
 
+    # activity_rate,monitor_rateの追加。PerformanceWarningが出ないようにするため、まとめて列を追加する
+    added_column_list = []
     for username in username_list:
-        df2[(username, "activity_rate")] = df2[(username, "worktime_actual")] / df2[(username, "worktime_planned")]
-        df2[(username, "monitor_rate")] = df2[(username, "worktime_monitored")] / df2[(username, "worktime_actual")]
+        s1 = pandas.Series(
+            df2[(username, "worktime_actual")] / df2[(username, "worktime_planned")], name=(username, "activity_rate")
+        )
+        s2 = pandas.Series(
+            df2[(username, "worktime_monitored")] / df2[(username, "worktime_actual")], name=(username, "monitor_rate")
+        )
+        added_column_list.extend([s1, s2])
 
-    # 比率がNaNの場合は"--"に置換する
-    df2.replace(
+    df_added_rate = pandas.concat(added_column_list, axis="columns")
+    df2 = pandas.concat([df2, df_added_rate], axis="columns")
+
+    # 比率がNaNの場合は"--"に置換した上で、列の順番を変える。
+    df2 = df2.round(2).replace(
         {col: DEFAULT_TO_REPLACE_FOR_VALUE for col in df2.columns if col[1] in ["activity_rate", "monitor_rate"]},
-        inplace=True,
-    )
-
-    # 列の順番を整える
-    df2 = df2[
+    )[
         [
             (m, v)
             for m in username_list
             for v in ["worktime_planned", "worktime_actual", "worktime_monitored", "activity_rate", "monitor_rate"]
         ]
     ]
+
     # date列を作る
     df2.reset_index(inplace=True)
-    return df2.round(2)
+    return df2
 
 
 def create_df_from_intermediate(
@@ -354,11 +367,11 @@ def create_df_from_intermediate(
     elif format_target == FormatTarget.COLUMN_LIST:
         df_output = create_df_with_format_column_list(df_intermediate)
 
-    elif format_target == FormatTarget.BY_USER:
-        df_output = create_df_with_format_by_user(df_intermediate)
+    elif format_target == FormatTarget.TOTAL_BY_USER:
+        df_output = create_df_with_format_total_by_user(df_intermediate)
 
-    elif format_target == FormatTarget.BY_PROJECT:
-        df_output = create_df_with_format_by_project(df_intermediate)
+    elif format_target == FormatTarget.TOTAL_BY_PROJECT:
+        df_output = create_df_with_format_total_by_project(df_intermediate)
 
     elif format_target == FormatTarget.TOTAL:
         df_output = create_df_with_format_total(df_intermediate)
@@ -616,8 +629,8 @@ def main(args):
 FORMAT_HELP_MESSAGE = (
     "出力する際のフォーマットを指定してください。\n"
     "・details: 日毎/人毎の詳細な作業時間を出力します。\n"
-    "・by_user:人毎の作業時間を出力します。\n"
-    "・by_project:プロジェクト毎の作業時間を出力します。\n"
+    "・total_by_user:人毎の作業時間を出力します。\n"
+    "・total_by_project:プロジェクト毎の作業時間を出力します。\n"
     "・total: 作業時間の合計値を出力します。\n"
     "・column_list:列固定で詳細な値を出力します。\n"
     "・column_list_per_project: 列固定で、日、メンバ、AnnoFabプロジェクトごとの作業時間を出力します。\n"
@@ -634,7 +647,8 @@ def parse_args(parser: argparse.ArgumentParser):
         type=str,
         required=True,
         nargs="+",
-        help="集計対象のプロジェクトのproject_idを指定します。複数指定した場合は合計値を出力します。\n" "`file://`を先頭に付けると、project_idの一覧が記載されたファイルを指定できます。",
+        help="集計対象のプロジェクトのproject_idを指定します。複数指定した場合は合計値を出力します。\n"
+        " ``file://`` を先頭に付けると、project_idの一覧が記載されたファイルを指定できます。",
     )
     parser.add_argument("--start_date", type=str, required=True, help="集計開始日(YYYY-mm-dd)")
     parser.add_argument("--end_date", type=str, required=True, help="集計終了日(YYYY-mm-dd)")
@@ -650,7 +664,7 @@ def parse_args(parser: argparse.ArgumentParser):
         type=str,
         nargs="+",
         required=False,
-        help="集計対象のユーザのuser_idを指定します。\n" "`file://`を先頭に付けると、user_idの一覧が記載されたファイルを指定できます。",
+        help="集計対象のユーザのuser_idを指定します。\n" " ``file://`` を先頭に付けると、user_idの一覧が記載されたファイルを指定できます。",
     )
     argument_parser.add_output(required=False)
 
