@@ -13,6 +13,7 @@ from typing import Any, Dict, List, Optional
 import annofabapi
 import pandas
 import requests
+from annofabapi.exceptions import CheckSumError
 from annofabapi.models import ProjectJobType, ProjectMemberRole
 from dataclasses_json import DataClassJsonMixin
 
@@ -179,6 +180,15 @@ class SubPutInputData:
                 f"input_data_name={input_data.input_data_name}"
             )
             return False
+        except CheckSumError as e:
+            logger.warning(e)
+            logger.warning(
+                f"入力データを登録しましたが、データが破損している可能性があります。"
+                f"input_data_id={input_data.input_data_id}, "
+                f"input_data_name={input_data.input_data_name},"
+                f"input_data_name={input_data.input_data_path},"
+            )
+            return False
 
 
 class PutInputData(AbstractCommandLineInterface):
