@@ -1,7 +1,7 @@
 import argparse
 import logging
 from enum import Enum
-from typing import Any, Callable
+from typing import Any, Callable, Optional
 
 from annofabapi.models import JobStatus, ProjectJobType
 
@@ -197,7 +197,7 @@ def parse_args(parser: argparse.ArgumentParser):
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "download"
     subcommand_help = "タスクや検査コメント、アノテーションなどをダウンロードします。"
     description = (
@@ -208,3 +208,4 @@ def add_parser(subparsers: argparse._SubParsersAction):
 
     parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description, epilog=epilog)
     parse_args(parser)
+    return parser
